/*
 * COPYRIGHT 2023 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 * The contents of this file are proprietary and confidential.
 * Unauthorised copying of this file, via any medium is strictly prohibited.
 */

#import <Foundation/Foundation.h>
#import <YOAdManagement/YOSessionErrors.h>

/**
 * @brief Represents a tracking error.
 *
 * Encapsulates the data of a tracking error when beacon tracking failed.
 */
@interface YOTrackingError : YOSessionErrors

/**
 Beacon URL String as returned in the tracking report, before macro substitutions.
 May be an empty string or malformed URL.
 */
@property (nullable) NSString* url;

/**
 Valid error codes are HTTP status codes from 300 to 599, -1 and -2.
 */
@property NSInteger errorCode;

/**
 Type of beacon event ('firstQuartile', etc.).
 */
@property (nullable) NSString* event;

/**
 The ad break identifier that the tracking beacon is associated with.
 Note that the identifier is an optional attribute; this property may be empty.
 */
@property (nullable) NSString* adbreakIdentifier;

/**
 The Yospace media identifier that the tracking beacon is associated with.
 */
@property (nullable) NSString* mediaIdentifier;

/**
 Timestamp in UTC in the format "2023-01-29T18:46:193Z"
 */
@property (nullable) NSString* utcTimestamp;

/**
 * @return a JSON representation of this tracking error.
 */
- (nonnull NSString*) toJsonString;

@end
